==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPaneHeaderElementDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescriptionMetadata } from "./WebDragServiceDescriptionMetadata";
import { WebPaneHeaderElementDescription } from "./WebPaneHeaderElementDescription";
/**
 * @hidden
 */
export let WebPaneHeaderElementDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneHeaderElementDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneHeaderElementDescriptionMetadata.a == null) {
                WebPaneHeaderElementDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneHeaderElementDescriptionMetadata.c(WebPaneHeaderElementDescriptionMetadata.a);
            }
            if (a.k(WebPaneHeaderElementDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPaneHeaderElementDescriptionMetadata.a);
            WebDragServiceDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneHeaderElement");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("DragService", "ExportedType:WebDragService");
        }
        static d(a) {
            WebPaneHeaderElementDescriptionMetadata.b(a);
            a.ad("WebPaneHeaderElement", () => new WebPaneHeaderElementDescription());
            a.ac("WebPaneHeaderElement", WebPaneHeaderElementDescriptionMetadata.a);
        }
    }
    WebPaneHeaderElementDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneHeaderElementDescriptionMetadata, 'WebPaneHeaderElementDescriptionMetadata');
    WebPaneHeaderElementDescriptionMetadata.a = null;
    return WebPaneHeaderElementDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebPaneHeaderElementDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescriptionMetadata } from "./WebDragServiceDescriptionMetadata";
import { WebPaneHeaderElementDescription } from "./WebPaneHeaderElementDescription";
/**
 * @hidden
 */
export let WebPaneHeaderElementDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneHeaderElementDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneHeaderElementDescriptionMetadata.a == null) {
                WebPaneHeaderElementDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneHeaderElementDescriptionMetadata.c(WebPaneHeaderElementDescriptionMetadata.a);
            }
            if (a.k(WebPaneHeaderElementDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPaneHeaderElementDescriptionMetadata.a);
            WebDragServiceDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneHeaderElement");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("DragService", "ExportedType:WebDragService");
        }
        static d(a) {
            WebPaneHeaderElementDescriptionMetadata.b(a);
            a.ae("WebPaneHeaderElement", () => new WebPaneHeaderElementDescription());
            a.ad("WebPaneHeaderElement", WebPaneHeaderElementDescriptionMetadata.a);
        }
    }
    WebPaneHeaderElementDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneHeaderElementDescriptionMetadata, 'WebPaneHeaderElementDescriptionMetadata');
    WebPaneHeaderElementDescriptionMetadata.a = null;
    return WebPaneHeaderElementDescriptionMetadata;
})();
